@@ -97,6 +97,25 @@ struct SIGC_API signal_impl
    */
   size_type size() const;
 
+  /** Returns whether all slots in the list are blocked.
+   * @return @p true if all slots are blocked or the list is empty.
+   *
+   * @newin{2,4}
+   */
+  bool blocked() const;
+
+  /** Sets the blocking state of all slots in the list.
+   * If @e should_block is @p true then the blocking state is set.
+   * Subsequent emissions of the signal don't invoke the functors
+   * contained in the slots until block() with @e should_block = @p false is called.
+   * sigc::slot_base::block() and sigc::slot_base::unblock() can change the
+   * blocking state of individual slots.
+   * @param should_block Indicates whether the blocking state should be set or unset.
+   *
+   * @newin{2,4}
+   */
+  void block(bool should_block = true);
+
   /** Adds a slot at the bottom of the list of slots.
    * @param slot_ The slot to add to the list of slots.
    * @return An iterator pointing to the new slot in the list.
@@ -263,6 +282,32 @@ struct SIGC_API signal_base : public trackable
    */
   size_type size() const;
 
+  /** Returns whether all slots in the list are blocked.
+   * @return @p true if all slots are blocked or the list is empty.
+   *
+   * @newin{2,4}
+   */
+  bool blocked() const;
+
+  /** Sets the blocking state of all slots in the list.
+   * If @e should_block is @p true then the blocking state is set.
+   * Subsequent emissions of the signal don't invoke the functors
+   * contained in the slots until unblock() or block() with
+   * @e should_block = @p false is called.
+   * sigc::slot_base::block() and sigc::slot_base::unblock() can change the
+   * blocking state of individual slots.
+   * @param should_block Indicates whether the blocking state should be set or unset.
+   *
+   * @newin{2,4}
+   */
+  void block(bool should_block = true);
+
+  /** Unsets the blocking state of all slots in the list..
+   *
+   * @newin{2,4}
+   */
+  void unblock();
+
 protected:
   typedef internal::signal_impl::iterator_type iterator_type;
 
